#!/bin/sh

die() {
   [ -n "$1" ] && echo $1
   exit 1
}

mrmkdir() {
   echo "creating directory \"$1\" ..."
   mkdir -p "$1" || die "ERROR creating directory \"$1\" !"
}

mrcp() {
   echo "copying file \"$1\" to \"$2\" ..."
   cp "$1" "$2" || die "ERROR copying file \"$1\" !"
}

usage() {
   test -n "$1" && echo "$1"
   cat << EOI
usage: install.sh [options] path_to_feyrules

valid options are:

    -h, --help    : show this help screen
    -f, --force   : override version check
EOI
   test -n "$1" && exit 1 
   exit
}

if test -z "$1"; then
   usage
fi

while test -z "$break"; do
   case $1 in
      "-h"|"--help")  usage   ;;
      "-f"|"--force") force=1 ;;
      *)
         test -z "$2" || usage "unknown option: \"$1\""
         break=1
         ;;
   esac
   test -z "$break" && shift
done

[ -f "./FeynRulesPackage.patch"  ] || die \
   "ERROR: please call from the FeynRules installation directory!"

[ -f "$1/FeynRulesPackage.m" ] || die \
   "ERROR: \"$1\" does not point to a FeynRules installation!"

vstring=`grep 'FR$VersionNumber =' "$1/FeynRulesPackage.m" | 
   sed 's/^ *FR\$VersionNumber *= *"\(.*\)";/\1/'`
test -z "$force" && test `echo $vstring  | sed "s/\.//g"` -ge 149 && die \
   'ERROR: Unsupported FeynRules version - please use 1.4.0 - 1.4.8
(or try "-f" to override the versio check)!'

[ -f "$1/Interfaces/WhizardOmegaInterface.m" ] && die \
   "ERROR: Interface is already installed, please use a fresh FeynRules installation!"

#
cat <<EOI
copying files...
===
EOI
dirs=`find ./Interfaces -not -regex '.*\.svn.*' -type d`
files=`find ./Interfaces -not -regex '.*\.svn.*' -type f`
efiles=`find ./examples -not -regex '.*\.svn.*' -type f`
for dir in $dirs; do
   [ -d "$1/$dir" ] || mrmkdir "$1/$dir"
done
for file in $files; do
   mrcp "$file" "${1%/}/${file%/*}"
done
for file in $efiles; do
   mrcp "$file" "$1"
done

#
cat <<EOI
===

patching files...
===
EOI
patch -d "$1" -p1 < "FeynRulesPackage.patch" || die \
   "ERROR applying patch"

#
cat << EOI
===

... all done! In order to verify the installation, you can run the examples
which have been copied to "$1" like e.g.

   cd "$1"
   math < wo_test_sm_1.93.m

(remember to wipe StandardModelWO prior to running any of the tests).
EOI
